/* adc_timer1
 *  
 * Az A0 bemenetre kapcsolt jel alakának vizsgálata ADC-vel, tároló módban. 
 * Az ADC konverziók indítását Timer1 megszakításokkal végezzük. 
 * Timer1 periódusát az OCR1A regiszter és az előosztó szabja meg. 
 * Az előosztással 2 MHz-es órajelet küldünk a számláló bemenetére.
 * A programban szereplő 39-es érték 40 ciklus, azaz 20 us időzítést jelent.
 * 
 * Az ADC órajelét 1 MHz-re vesszük, így nem használható ki a
 * 10 bites felbontás.
 * 
 * A program eredetijének forrása:
 * https://www.gammon.com.au/adc
 */
const byte adcPin = 0;                // A0
const int MAX_RESULTS = 512;          // Mérések száma
volatile byte results[MAX_RESULTS];   // Adattároló tömb
volatile int resultNumber = 0;        // Számláló

//-- ADC konverzió vége megszakítás ----
ISR (ADC_vect) {
  if (resultNumber >= MAX_RESULTS)
    ADCSRA = 0;  // turn off ADC
  else
    results [resultNumber++] = ADC >> 2;
}

//-- Timer1 megszakítása nem igényel kiszolgálást ---
EMPTY_INTERRUPT (TIMER1_COMPB_vect);

void setup () {
  Serial.begin (115200);
  Serial.println ();
  //-- Timer 1 konfigurálása --------
  TCCR1A = 0;
  TCCR1B = 0;
  TCNT1 = 0;
  TCCR1B = bit(CS11) | bit(WGM12);    // CTC, előosztó = /8
  TIMSK1 = bit(OCIE1B);               // Timer1 OC1B megszakítás engedélyezés
  OCR1A = 39;                         // 20 uS - sampling frequency 50 kHz
  OCR1B = 39;                         // Megadja, mikor történjen a triggerelés
//--- ADC configuration -------------
  ADCSRA =  bit(ADEN) | bit(ADIE) | bit(ADIF);   // ADC bekapcsolás, megszakítás engedélyezés
  ADCSRA |= bit(ADPS2);               // Előszámláló: /16 (1 MHz frekvencia)
  ADMUX = bit(REFS0) | (adcPin & 7);  // Vcc a referencia, csatorna kiválasztása
  ADCSRB = bit(ADTS0) | bit(ADTS2);   // Timer1 Compare Match B a triggerforrás
  ADCSRA |= bit(ADATE);               // Triggerelés engedélyezés

  //-- Várunk a méréssorozat végére ---------
  while (resultNumber < MAX_RESULTS);
  //-- Eredméynek kiírása a soros porton ----
  for (int i = 0; i < MAX_RESULTS; i++)
    Serial.println (results [i]);
}  // end of setup

void loop () { }
