/* switch_case
 * A switch utasítás használatának bemutatása. A switch utasítás lehetővé
 * teszi, hogy egy változó több lehetséges diszkrét értéke közül válasszunk
 * és  aprogramot eszerint elágaztassuk. Ez olyan, mintha több if - else if
 * utasítást használnánk.
 *
 * A program működésének megfigyeléséhez helyezzük a fényérzékeny ellenállát
 * tartalmazó áramkört egy jól megvilégított helyre, indítsuk be a soros
 * monitort, majd kezünkkel fokozatosan takarjuk el a fényérzékeny ellenállást!
 *
 * A kapcsolás:
 *  - fényérzékeny ellenállás (LDR) az A3 bemenet és az +5V közés
 *  - 10K ellenállás az A3 bemenet és GND közé
 *
 *        LDR      10k
 *  VCC--/\/\/\-+-/\/\/\--- GND
 *              |
 *              A3
 *
 *  Forrás: https://www.arduino.cc/en/Tutorial/switchCase
 *  Szerző: Tom Igoue
 *  Magyar változat: István Cserny
 *
 */

const int sensorMin = 0;        // szenzor minimum (tapasztalat alapján)
const int sensorMax = 800;      // szensor maximum (tapasztalat alapján)

void setup() {
  Serial.begin(9600);           // Soros port inicializálása
}

void loop() {
  int reading = analogRead(A3); // Szenzor kiolvasás
  // A mérési tartomány leképezése négy esetre
  int range = map(reading, sensorMin, sensorMax, 0, 3);
  switch (range) {
    case 0:     // Eltakart szenzor esetén
      Serial.println("sötét");
      break;
    case 1:     // kezed közel a szenzorhoz
      Serial.println("derengő fény");
      break;
    case 2:     // kezed 10 cm-re a szenzortól
      Serial.println("közepes fény");
      break;
    case 3:     // kezed nincs a fény útjában
      Serial.println("erős fény");
      break;
  }
  delay(1000);  // Késleltetés a kiíratások között
}
